import { AuthServiceService } from './../../../shared/auth-service.service';
import { NgxSpinnerService } from 'ngx-spinner';
import { ActivatedRoute, Router, Params } from '@angular/router';
import { DashboardService } from './../../../shared/dashboard.service';
import { HttpClient } from '@angular/common/http';
import { Component, OnInit } from '@angular/core';
import { Modal } from 'ngx-modialog/plugins/bootstrap';
import { UserService } from '../../../shared/user.service';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-bar-events-list',
  templateUrl: './bar-events-list.component.html',
  styleUrls: ['./bar-events-list.component.css']
})

export class BarEventsListComponent implements OnInit {

  constructor(private http: HttpClient,
    private route: ActivatedRoute,
    private router: Router,
    private modal: Modal,
    private userSer: UserService,
    private spinner: NgxSpinnerService,
    private authSer: AuthServiceService,
    private toastr: ToastrService,
    private dashboardSer: DashboardService) { }

    barEventsList = [];
    pages= [];
    pageId: number;
    barEventsListIds = [];
    count: number;
    perPagePagenation: number;
    currentPage:number = 1;
    filtterStatus = '';
    selectedAll: any;
    userLoginId:number;
    serviceId:number;
    dataTableNumber: number = 5;

    ngOnInit() {
      //init values of permisions
      this.authSer.showAddBtn = false;
      this.authSer.showDeleteBtn = false;
      this.authSer.showEditBtn = false;
      this.authSer.showPermissionsBtn = false;
      //show / hide notification search in header
      this.authSer.notificationLogin = true;
      this.authSer.showSearchHeader = false;
      this.authSer.showHeaderLogin = false;
      this.authSer.showHeaderDashBoard = true;
      this.authSer.showDashboardHeader = true;
      this.authSer.internalHeader = false;
      //to show / hide permissions

      this.route.params.subscribe(
        (parmas: Params) => {
          this.pageId = parmas['listPageId'];
          localStorage.setItem('pageIdActive', parmas['listPageId']);
        }
      );

      this.route.parent.params.subscribe(
        (params:Params) => {
          this.userLoginId = params['userID'];
          this.serviceId = params['serviceID'];
          this.userSer.getPagesPermetiotns(this.userLoginId, this.serviceId).subscribe(
            (responce) => {
              console.log(responce);
              this.pages = responce['pages'];
              for(let i = 0; i< this.pages.length; i++) {
                if(this.pages[i].id == 21) {
                  for(let j = 0; j < this.pages[i].permissions.length; j++) {
                    if(this.pages[i].permissions[j].name == "add_event_bar"){
                      this.authSer.showAddBtn = true;
                    }
                    if(this.pages[i].permissions[j].name == "edit_event_bar"){
                      this.authSer.showEditBtn = true;
                    }
                    if(this.pages[i].permissions[j].name == "delete_event_bars"){
                      this.authSer.showDeleteBtn = true;
                    }
                  }
                }else {
                  console.log('no events');
                }
              }
              this.spinner.hide();
            },
            (error) => {console.log(error)}
          );
        }
      );

      

      this.dashboardSer.getListData(this.pageId, this.currentPage, this.dataTableNumber).subscribe(
        (responce) => {
          console.log(responce);
          this.barEventsList = responce['events'];
          this.count = responce['count'];
          this.perPagePagenation = responce['per_page'];
        },
        (error) => {
          console.log(error);
        }
      );

    } //end ngOnInit

    //make all checkbox of user checked
    selectAll() {
    for (var i = 0; i < this.barEventsList.length; i++) {
      this.barEventsList[i].selected = this.selectedAll;
    }
  };

  checkIfAllSelected() {
    this.selectedAll = this.barEventsList.every(function(item:any) {
      return item.selected == true;
    });
  };

  //filtter function
  filtterFunc(data) {
  this.barEventsList = [];
  console.log(data.target.value);
  const dataSearch = data.target.value;
  this.currentPage = 1;
  console.log('search curent page', this.currentPage);
  this.dashboardSer.getDataUSerSearchBar(dataSearch, this.pageId, this.currentPage, this.dataTableNumber).subscribe(
    (responce) => {
      console.log(responce);
      this.barEventsList = responce['events'];
      this.count = responce['count'];
      this.perPagePagenation = responce['per_page'];
      console.log('filtter count', this.count);
      console.log('filtter perPagePAgenation', this.perPagePagenation);
    },
    (error) => {
      console.log(error)
    }
  );
};

//change page
onPageChange(pagenationNumber) {
this.spinner.show();
this.currentPage = pagenationNumber;
this.barEventsList = [];
//console.log(pagenationNumber);
//console.log(this.pageId);
this.dashboardSer.getListData(this.pageId, pagenationNumber, this.dataTableNumber).subscribe(
(responce) => {
  console.log(responce);
  this.barEventsList = responce['events'];
  this.count = responce['count'];
  this.perPagePagenation = responce['per_page'];
  console.log(this.barEventsList);
  this.spinner.hide();
},
(error) => {
  console.log(error);
  this.spinner.hide();
}
);
};


//determine the list count from select element
onGetValue(event) {
this.spinner.show();
this.barEventsList = [];
this.dataTableNumber = event.target.value;
this.dashboardSer.getListData(this.pageId, this.currentPage, this.dataTableNumber).subscribe(
  (responce) => {
    console.log(responce);
    this.barEventsList = responce['events'];
    this.count = responce['count'];
    this.perPagePagenation = responce['per_page'];
    this.spinner.hide();
  },
  (error) => {
    console.log(error);
    this.spinner.hide();
  }
);
}

onDelete() {

  this.barEventsListIds = [];
  for(let i = 0; i < this.barEventsList.length; i++) {
    if(this.barEventsList[i].selected == true) {
      this.barEventsListIds.push(this.barEventsList[i].id);
    }
  }

  console.log(this.barEventsListIds);

  if(this.barEventsListIds.length > 0) {
    const dialogRef = this.modal.alert()
    .size('sm')
    .showClose(true)
    .title('تأكيد الحذف')
    .body(`
      <h4>هل ترغب في حذف العناصر المحدده ؟ </h4>
      `)
      .open();

      dialogRef.result
      .then( result =>
        this.dashboardSer.deleteItem(this.barEventsListIds, this.pageId).subscribe(
          (responce) => {
            console.log(responce);
            this.toastr.success('تم الحذف');
            this.spinner.show();
            this.barEventsList = [];
            this.dashboardSer.getListData(this.pageId, this.currentPage, this.dataTableNumber).subscribe(
              (responce) => {
                console.log(responce);
                this.barEventsList = responce['events'];
                this.count = responce['count'];
                this.perPagePagenation = responce['per_page'];
                this.spinner.hide();
              },
              (error) => {
                console.log(error);
                this.spinner.hide();
              }
            );
          },
          (error) => {
            console.log(error);
            this.spinner.hide();
          },
        )
      );
    } else {
      this.toastr.warning('لم يتم إختيار أي عنصر للمسح !');
    }
  };

  //add function
  onAdd() {
  console.log('service/' + this.userLoginId + '/' + this.serviceId + '/barEvent/add');
  this.router.navigate(['service/' + this.userLoginId + '/' + this.serviceId + '/barEvent/add']);
}

//edit function
onEdit(editTabID) {
localStorage.setItem('editbarEventIdStorage', editTabID);
this.router.navigate(['service/' + this.userLoginId + '/' + this.serviceId + '/barEvent/edit/']);
console.log('service/' + this.userLoginId + '/' + this.serviceId + '/barEvent/edit/');
};

}
